@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	fontSize: "Μέγεθος",
 	fontName: "Γραμματοσειρά",
@@ -9,6 +11,7 @@
 	cursive: "πλάγιοι",
 	fantasy: "φαντασίας",
 
+	noFormat: "Χωρίς",
 	p: "Παράγραφος",
 	h1: "Επικεφαλίδα",
 	h2: "Δευτερεύουσα επικεφαλίδα",
@@ -22,4 +25,6 @@
 	5: "μεγάλα",
 	6: "x-μεγάλα",
 	7: "xx-μεγάλα"
-})
\ No newline at end of file
+})
+//end v1.x content
+);
