@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	fontSize: "Størrelse",
 	fontName: "Skrift",
@@ -9,6 +11,7 @@
 	cursive: "kursiv",
 	fantasy: "fantasi",
 
+	noFormat: "Ingen",
 	p: "Avsnitt",
 	h1: "Overskrift",
 	h2: "Undertittel",
@@ -22,4 +25,6 @@
 	5: "stor",
 	6: "x-stor",
 	7: "xx-stor"
-})
\ No newline at end of file
+})
+//end v1.x content
+);
