@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	fontSize: "Veľkosť",
 	fontName: "Písmo",
@@ -9,6 +11,7 @@
 	cursive: "cursive",
 	fantasy: "fantasy",
 
+	noFormat: "Žiadny",
 	p: "Odsek",
 	h1: "Hlavička",
 	h2: "Podhlavička",
@@ -23,4 +26,6 @@
 	6: "x-large",
 	7: "xx-large"
 })
+//end v1.x content
+);
 
