@@ -1,6 +1,10 @@
+define(
+//begin v1.x content
 ({
 	buttonOk: "OK",
 	buttonCancel: "Cancelar",
 	buttonSave: "Guardar",
 	itemClose: "Fechar"
-})
\ No newline at end of file
+})
+//end v1.x content
+);
