@@ -1,14 +1,8 @@
-dojo.provide("tests.data.ItemFileWriteStore");
-dojo.require("tests.data.readOnlyItemFileTestTemplates");
+define("tests/data/ItemFileWriteStore", ["dojo", "tests/data/readOnlyItemFileTestTemplates", "dojo/data/ItemFileWriteStore", "dojo/data/api/Read", "dojo/data/api/Identity", "dojo/data/api/Write", "dojo/data/api/Notification"], function(dojo) {
 
-dojo.require("dojo.data.ItemFileWriteStore");
-dojo.require("dojo.data.api.Read");
-dojo.require("dojo.data.api.Identity");
-dojo.require("dojo.data.api.Write");
-dojo.require("dojo.data.api.Notification");
+dojo.getObject("data.ItemFileWriteStore", true, tests);
 
-
-// First, make sure ItemFileWriteStore can still pass all the same unit tests 
+// First, make sure ItemFileWriteStore can still pass all the same unit tests
 // that we use for its superclass, ItemFileReadStore:
 tests.data.readOnlyItemFileTestTemplates.registerTestsForDatastore("dojo.data.ItemFileWriteStore");
 
@@ -18,8 +12,8 @@ tests.data.ItemFileWriteStore.getTestData = function(name){
 		if(dojo.isBrowser){
 			data = {url: dojo.moduleUrl("tests", "data/reference_integrity.json").toString() };
 		}else{
-			data = 
-				{ data: { 
+			data =
+				{ data: {
 					"identifier": "id",
 					"label": "name",
 					"items": [
@@ -48,16 +42,16 @@ tests.data.ItemFileWriteStore.getTestData = function(name){
 
 
 // Now run some tests that are specific to the write-access features:
-doh.register("tests.data.ItemFileWriteStore", 
+doh.register("tests.data.ItemFileWriteStore",
 	[
 		function test_getFeatures(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the getFeatures function of the store
 			//	description:
 			//		Simple test of the getFeatures function of the store
 			var store = new dojo.data.ItemFileWriteStore(tests.data.readOnlyItemFileTestTemplates.getTestData("countries"));
 
-			var features = store.getFeatures(); 
+			var features = store.getFeatures();
 
 			// make sure we have the expected features:
 			doh.assertTrue(features["dojo.data.api.Read"] !== null);
@@ -69,16 +63,16 @@ doh.register("tests.data.ItemFileWriteStore",
 			// and only the expected features:
 			var count = 0;
 			for(var i in features){
-				doh.assertTrue((i === "dojo.data.api.Read" || 
-					i === "dojo.data.api.Identity" || 
-					i === "dojo.data.api.Write" || 
+				doh.assertTrue((i === "dojo.data.api.Read" ||
+					i === "dojo.data.api.Identity" ||
+					i === "dojo.data.api.Write" ||
 					i === "dojo.data.api.Notification"));
 				count++;
 			}
 			doh.assertEqual(count, 4);
 		},
 		function testWriteAPI_setValue(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the setValue API
 			//	description:
 			//		Simple test of the setValue API
@@ -90,7 +84,7 @@ doh.register("tests.data.ItemFileWriteStore",
 				var item = items[0];
 				doh.assertTrue(store.containsValue(item, "capital", "Cairo"));
 				
-				// FIXME:  
+				// FIXME:
 				//    Okay, so this seems very odd.  Maybe I'm just being dense.
 				//    These tests works:
 				doh.assertEqual(store.isDirty(item), false);
@@ -98,7 +92,7 @@ doh.register("tests.data.ItemFileWriteStore",
 				//    But these seemingly equivalent tests will not work:
 				// doh.assertFalse(store.isDirty(item));
 				// doh.assertTrue(!(store.isDirty(item)));
-				//   
+				//
 				//    All of which seems especially weird, given that this *does* work:
 				doh.assertFalse(store.isDirty());
 				
@@ -117,7 +111,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_setValues(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the setValues API
 			//	description:
 			//		Simple test of the setValues API
@@ -145,7 +139,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_unsetAttribute(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the unsetAttribute API
 			//	description:
 			//		Simple test of the unsetAttribute API
@@ -171,7 +165,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_newItem(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the newItem API
 			//	description:
 			//		Simple test of the newItem API
@@ -207,7 +201,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_newItem_withParent(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the newItem API with a parent assignment
 			//	description:
 			//		Simple test of the newItem API with a parent assignment
@@ -266,7 +260,7 @@ doh.register("tests.data.ItemFileWriteStore",
 		},
 		
 		function testWriteAPI_newItem_multiple_withParent(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the newItem API with a parent assignment multiple times.
 			//	description:
 			//		Simple test of the newItem API with a parent assignment multiple times.
@@ -331,7 +325,7 @@ doh.register("tests.data.ItemFileWriteStore",
 		},
 
 		function testWriteAPI_deleteItem(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the deleteItem API
 			//	description:
 			//		Simple test of the deleteItem API
@@ -362,7 +356,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_isDirty(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the isDirty API
 			//	description:
 			//		Simple test of the isDirty API
@@ -385,7 +379,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_revert(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the revert API
 			//	description:
 			//		Simple test of the revert API
@@ -422,7 +416,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_save(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the save API
 			//	description:
 			//		Simple test of the save API
@@ -443,7 +437,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_saveVerifyState(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the save API
 			//	description:
 			//		Simple test of the save API
@@ -467,7 +461,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_saveEverything(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the save API
 			//	description:
 			//		Simple test of the save API
@@ -507,7 +501,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_saveEverything_HierarchyOff(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the save API
 			//	description:
 			//		Simple test of the save API
@@ -543,7 +537,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_saveEverything_withDateType(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the save API	with a non-atomic type (Date) that has a type mapping.
 			//	description:
 			//		Simple test of the save API	with a non-atomic type (Date) that has a type mapping.
@@ -557,7 +551,7 @@ doh.register("tests.data.ItemFileWriteStore",
 				var newStore = new dojo.data.ItemFileWriteStore({data: dataset});
 
 				function gotItem(item){
-					var independenceDate = newStore.getValue(item,"independence"); 
+					var independenceDate = newStore.getValue(item,"independence");
 					doh.assertTrue(independenceDate instanceof Date);
 					doh.assertTrue(dojo.date.compare(new Date(1993,4,24), independenceDate, "date") === 0);
 					saveCompleteCallback();
@@ -583,7 +577,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_saveEverything_withCustomColorTypeSimple(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the save API	with a non-atomic type (dojo.Color) that has a type mapping.
 			//	description:
 			//		Simple test of the save API	with a non-atomic type (dojo.Color) that has a type mapping.
@@ -614,7 +608,7 @@ doh.register("tests.data.ItemFileWriteStore",
 
 				var deferred = new doh.Deferred();
 				function gotItem(item){
-					var hairColor = newStore.getValue(item,"hairColor"); 
+					var hairColor = newStore.getValue(item,"hairColor");
 					doh.assertTrue(hairColor instanceof dojo.Color);
 					doh.assertEqual("rgba(255, 255, 0, 1)", hairColor.toString());
 					saveCompleteCallback();
@@ -639,7 +633,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_saveEverything_withCustomColorTypeGeneral(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the save API	with a non-atomic type (dojo.Color) that has a type mapping.
 			//	description:
 			//		Simple test of the save API	with a non-atomic type (dojo.Color) that has a type mapping.
@@ -655,7 +649,7 @@ doh.register("tests.data.ItemFileWriteStore",
 				]
 			};
 
-			var customTypeMap = {'Color': 	{	
+			var customTypeMap = {'Color': 	{
 												type: dojo.Color,
 												deserialize: function(value){
 													return new dojo.Color(value);
@@ -677,7 +671,7 @@ doh.register("tests.data.ItemFileWriteStore",
 				var newStore = new dojo.data.ItemFileWriteStore({data: dataset, typeMap: customTypeMap});
 
 				var gotItem = function(item){
-					var hairColor = newStore.getValue(item,"hairColor"); 
+					var hairColor = newStore.getValue(item,"hairColor");
 					doh.assertTrue(hairColor instanceof dojo.Color);
 					doh.assertEqual("rgba(255, 255, 0, 1)", hairColor.toString());
 					saveCompleteCallback();
@@ -702,7 +696,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_newItem_revert(){
-			//	summary: 
+			//	summary:
 			//		Test for bug #5357.  Ensure that the revert properly nulls the identity position
 			//      for a new item after revert.
 			var args = {data: {
@@ -716,7 +710,7 @@ doh.register("tests.data.ItemFileWriteStore",
 					{name:'Estonia', capital:'Tallinn'},
 					{name:'Ethiopia', capital:'Addis Ababa'}
 				]
-			} }; 
+			} };
 			var store = new dojo.data.ItemFileWriteStore(args);
 
 			var newCountry = store.newItem({name: "Utopia", capitol: "Perfect"});
@@ -728,7 +722,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			doh.assertTrue(store._arrayOfAllItems[itemEntryNum] === null);
 		},
 		function testWriteAPI_new_modify_revert(){
-			//	summary: 
+			//	summary:
 			//		Test of a new item, modify it, then revert, to ensure the state remains consistent.  Added due to #9022.
 			//	description:
 			//		Test of a new item, modify it, then revert, to ensure the state remains consistent.  Added due to #9022.
@@ -762,7 +756,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testWriteAPI_new_modify_delete_revert(){
-			//	summary: 
+			//	summary:
 			//		Test of a new item, modify it, delete it, then revert, to ensure the state remains consistent.  Added due to #9022.
 			//	description:
 			//		Test of a new item, modify it, delete it, then revert, to ensure the state remains consistent.  Added due to #9022.
@@ -788,7 +782,7 @@ doh.register("tests.data.ItemFileWriteStore",
 					doh.assertEqual(afterNewCount, (initialCount + 1));
 					store.deleteItem(canada);
 					
-					//Check that after delete, the total items count goes back to initial count.  
+					//Check that after delete, the total items count goes back to initial count.
 					//Also verify the item with abbr of ca is gone.
 					var afterDeleteFetch = function(items, request){
 						var afterDeleteCount = items.length;
@@ -796,7 +790,7 @@ doh.register("tests.data.ItemFileWriteStore",
 
 						for(i=0; i < items.length; i++){
 							found = (store.getIdentity(items[i]) === "ca");
-							if(found){ 
+							if(found){
 								break;
 							}
 						}
@@ -804,14 +798,14 @@ doh.register("tests.data.ItemFileWriteStore",
 							deferred.errback(new Error("Error: Found the supposedly deleted item!"));
 						}else{
 							store.revert();
-							//Check that after revert, we still have the same item count as the 
+							//Check that after revert, we still have the same item count as the
 							//original fetch.  Also verify the item with abbr of ca is gone.
 							var afterRevertFetch = function(items, request){
 								var afterRevertCount = items.length;
 								doh.assertEqual(afterRevertCount, initialCount);
 								for(i=0; i < items.length; i++){
 									found = (store.getIdentity(items[i]) === "ca");
-									if(found){ 
+									if(found){
 										break;
 									}
 								}
@@ -832,7 +826,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred; //Object
 		},
 		function testNotificationAPI_onSet(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the onSet API
 			//	description:
 			//		Simple test of the onSet API
@@ -860,7 +854,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			store.fetchItemByIdentity({identity:"eg", onItem:onItem, onError:onError});
 		},
 		function testNotificationAPI_onNew(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the onNew API
 			//	description:
 			//		Simple test of the onNew API
@@ -878,7 +872,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			var canada = store.newItem({name:"Canada", abbr:"ca", capital:"Ottawa"});
 		},
 		function testNotificationAPI_onDelete(){
-			//	summary: 
+			//	summary:
 			//		Simple test of the onDelete API
 			//	description:
 			//		Simple test of the onDelete API
@@ -903,7 +897,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			store.fetchItemByIdentity({identity:"eg", onItem:onItem, onError:onError});
 		},
 		function testReadAPI_functionConformanceToo(){
-			//	summary: 
+			//	summary:
 			//		Simple test read API conformance.  Checks to see all declared functions are actual functions on the instances.
 			//	description:
 			//		Simple test read API conformance.  Checks to see all declared functions are actual functions on the instances.
@@ -925,7 +919,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			doh.assertTrue(passed);
 		},
 		function testWriteAPI_functionConformance(){
-			//	summary: 
+			//	summary:
 			//		Simple test write API conformance.  Checks to see all declared functions are actual functions on the instances.
 			//	description:
 			//		Simple test write API conformance.  Checks to see all declared functions are actual functions on the instances.
@@ -947,7 +941,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			doh.assertTrue(passed);
 		},
 		function testNotificationAPI_functionConformance(){
-			//	summary: 
+			//	summary:
 			//		Simple test Notification API conformance.  Checks to see all declared functions are actual functions on the instances.
 			//	description:
 			//		Simple test Notification API conformance.  Checks to see all declared functions are actual functions on the instances.
@@ -969,9 +963,9 @@ doh.register("tests.data.ItemFileWriteStore",
 			doh.assertTrue(passed);
 		},
 		function testIdentityAPI_noIdentifierSpecified(){
-			//	summary: 
+			//	summary:
 			//		Test for bug #3873. Given a datafile that does not specify an
-			//		identifier, make sure ItemFileWriteStore auto-creates identities 
+			//		identifier, make sure ItemFileWriteStore auto-creates identities
 			//		that are unique even after calls to deleteItem() and newItem()
 			var args = {data: {
 				label:"name",
@@ -984,7 +978,7 @@ doh.register("tests.data.ItemFileWriteStore",
 					{name:'Estonia', capital:'Tallinn'},
 					{name:'Ethiopia', capital:'Addis Ababa'}
 				]
-			} }; 
+			} };
 			var store = new dojo.data.ItemFileWriteStore(args);
 			var deferred = new doh.Deferred();
 			
@@ -1022,9 +1016,9 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred;
 		},
 		function testIdentityAPI_noIdentifierSpecified_revert(){
-			//	summary: 
+			//	summary:
 			//		Test for bug #4691  Given a datafile that does not specify an
-			//		identifier, make sure ItemFileWriteStore auto-creates identities 
+			//		identifier, make sure ItemFileWriteStore auto-creates identities
 			//		that are unique even after calls to deleteItem() and newItem()
 			var args = {data: {
 				label:"name",
@@ -1037,7 +1031,7 @@ doh.register("tests.data.ItemFileWriteStore",
 					{name:'Estonia', capital:'Tallinn'},
 					{name:'Ethiopia', capital:'Addis Ababa'}
 				]
-			} }; 
+			} };
 			var store = new dojo.data.ItemFileWriteStore(args);
 			var deferred = new doh.Deferred();
 			
@@ -1082,7 +1076,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred;
 		},
 		function testReferenceIntegrity_checkReferences(){
-			//	summary: 
+			//	summary:
 			//		Simple test to verify the references were properly resolved.
 			//	description:
 			//		Simple test to verify the references were properly resolved.
@@ -1151,7 +1145,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred;
 		},
 		function testReferenceIntegrity_deleteReferencedItem(){
-			//	summary: 
+			//	summary:
 			//		Simple test to verify the references were properly deleted.
 			//	description:
 			//		Simple test to verify the references were properly deleted.
@@ -1206,7 +1200,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred;
 		},
 		function testReferenceIntegrity_deleteReferencedItemThenRevert(){
-			//	summary: 
+			//	summary:
 			//		Simple test to verify the references were properly deleted.
 			//	description:
 			//		Simple test to verify the references were properly deleted.
@@ -1220,7 +1214,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			}
 			function onItem(item, request){
 				try{
-					//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!  
+					//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!
 					//THIS IS FOR TESTING INTERNAL STATE!
 					console.log("Map before delete:");
 					store._dumpReferenceMap();
@@ -1246,7 +1240,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred;
 		},
 		function testReferenceIntegrity_deleteMultipleItemsWithReferencesAndRevert(){
-			//	summary: 
+			//	summary:
 			//		Simple test to verify that a flow of deleting items with references and reverting does not damage the internal structure.
 			//		Created for tracker bug: #5743
 			//	description:
@@ -1291,7 +1285,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred;
 		},
 		function testReferenceIntegrity_removeReferenceFromAttribute(){
-			//	summary: 
+			//	summary:
 			//		Simple test to verify the reference removal updates the internal map.
 			//	description:
 			//		Simple test to verify the reference removal updates the internal map.
@@ -1309,7 +1303,7 @@ doh.register("tests.data.ItemFileWriteStore",
 					store.setValues(item, "friends", [null]);
 
 					function onItem2(item10, request){
-						//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!  
+						//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!
 						//THIS IS FOR TESTING INTERNAL STATE!
 						var refMap = item10[store._reverseRefMap];
 						store._dumpReferenceMap();
@@ -1335,7 +1329,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred;
 		},
 		function testReferenceIntegrity_deleteReferencedItemNonParent(){
-			//	summary: 
+			//	summary:
 			//		Simple test to verify the references to a non-parent item was properly deleted.
 			//	description:
 			//		Simple test to verify the references to a non-parent item was properly deleted.
@@ -1389,7 +1383,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred;
 		},
 		function testReferenceIntegrity_addReferenceToAttribute(){
-			//	summary: 
+			//	summary:
 			//		Simple test to verify the reference additions can happen.
 			//	description:
 			//		Simple test to verify the reference additions can happen.
@@ -1409,7 +1403,7 @@ doh.register("tests.data.ItemFileWriteStore",
 				var item1 = items[0];
 				var item2 = items[1];
 
-				//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!  
+				//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!
 				//THIS IS FOR TESTING INTERNAL STATE!
 				console.log("Map state for Item 1 is: " + dojo.toJson(item1[store._reverseRefMap]));
 				console.log("Map state for Item 2 is: " + dojo.toJson(item2[store._reverseRefMap]));
@@ -1431,7 +1425,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred;
 		},
 		function testReferenceIntegrity_newItemWithParentReference(){
-			//	summary: 
+			//	summary:
 			//		Simple test to verify that newItems with a parent properly record the parent's reference in the map.
 			//	description:
 			//		Simple test to verify that newItems with a parent properly record the parent's reference in the map.
@@ -1447,9 +1441,9 @@ doh.register("tests.data.ItemFileWriteStore",
 			function onItem(item, request){
 				try{
 					//Create a new item and set its parent to item 10's uncle attribute.
-					var newItem = store.newItem({id: 17, name: "Item 17"}, {parent: item, attribute: "uncles"}); 
+					var newItem = store.newItem({id: 17, name: "Item 17"}, {parent: item, attribute: "uncles"});
 					
-					//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!  
+					//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!
 					//THIS IS FOR TESTING INTERNAL STATE!
 					//Look up the references to 17, as item 10 has one now on attribute 'uncles'
 					var refs = newItem[store._reverseRefMap];
@@ -1472,7 +1466,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred;
 		},
 		function testReferenceIntegrity_newItemWithReferenceToExistingItem(){
-			//	summary: 
+			//	summary:
 			//		Simple test to verify that a new item with references to existing items properly record the references in the map.
 			//	description:
 			//		Simple test to verify that a new item with references to existing items properly record the references in the map.
@@ -1487,14 +1481,14 @@ doh.register("tests.data.ItemFileWriteStore",
 			}
 			function onItem(item, request){
 				try{
-					//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!  
+					//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!
 					//THIS IS FOR TESTING INTERNAL STATE!
 					console.log("State of reference map to item 10 before newItem: " + dojo.toJson(item[store._reverseRefMap]));
 					
 					//Create a new item and set its parent to item 10's uncle attribute.
 					var newItem = store.newItem({id: 17, name: "Item 17", friends: [item]});
 					
-					//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!  
+					//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!
 					//THIS IS FOR TESTING INTERNAL STATE!
 					//Look up the references to 10, as item 17 has one on friends now.
 					var refs = item[store._reverseRefMap];
@@ -1517,7 +1511,7 @@ doh.register("tests.data.ItemFileWriteStore",
 			return deferred;
 		},
 		function testReferenceIntegrity_disableReferenceIntegrity(){
-			//	summary: 
+			//	summary:
 			//		Simple test to verify reference integrity can be disabled.
 			//	description:
 			//		Simple test to verify reference integrity can be disabled.
@@ -1532,7 +1526,7 @@ doh.register("tests.data.ItemFileWriteStore",
 				doh.assertTrue(false);
 			}
 			function onItem(item, request){
-				//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!  
+				//DO NOT EVER ACCESS THESE VARIABLES LIKE THIS!
 				//THIS IS FOR TESTING INTERNAL STATE!
 				if(item[store._reverseRefMap] === undefined){
 					deferred.callback(true);
@@ -1542,9 +1536,9 @@ doh.register("tests.data.ItemFileWriteStore",
 			}
 			store.fetchItemByIdentity({identity: 10, onError: onError, onItem: onItem});
 			return deferred;
-		}, 
+		},
 		function testReadAPI_close_dirty_failure(){
-			//	summary: 
+			//	summary:
 			//		Function to test the close api properly clears the store for reload when clearOnClose is set.
 			if (dojo.isBrowser) {
 				var params = tests.data.readOnlyItemFileTestTemplates.getTestData("countries");
@@ -1584,3 +1578,4 @@ doh.register("tests.data.ItemFileWriteStore",
 );
 
 
+});
\ No newline at end of file
