@@ -1,15 +1,15 @@
 ({
-	insertTableTitle: "Inserare tabelă",
-	modifyTableTitle: "Modificare tabelă",
+	insertTableTitle: "Inserare tabel",
+	modifyTableTitle: "Modificare tabel",
 	rows: "Rânduri:",
 	columns: "Coloane:",
 	align: "Aliniere:",
-	cellPadding: "Completare celulă:",
+	cellPadding: "Padding celulă:",
 	cellSpacing: "Spaţiere celulă:",
 	tableWidth: "Lăţime tabelă:",
-	backgroundColor: "Culoare fundal:",
-	borderColor: "Culoare bordură:",
-	borderThickness: "Grosime bordură",
+	backgroundColor: "Culoare de fundal:",
+	borderColor: "Coloare de bordură:",
+	borderThickness: "Grosime de bordură:",
 	percent: "procent",
 	pixels: "pixeli",
 	"default": "implicit",
@@ -18,13 +18,15 @@
 	right: "dreapta",
 	buttonSet: "Setare", // translated elsewhere?
 	buttonInsert: "Inserare",
+	buttonCancel: "Anulare",
 
-	selectTableLabel: "Selectare tabelă ",
+	selectTableLabel: "Selectare tabelă",
 	insertTableRowBeforeLabel: "Adăugare rând înainte",
 	insertTableRowAfterLabel: "Adăugare rând după",
 	insertTableColumnBeforeLabel: "Adăugare coloană înainte",
 	insertTableColumnAfterLabel: "Adăugare coloană după",
-	deleteTableRowLabel: "Ştergere rând ",
+	deleteTableRowLabel: "Ştergere rând",
 	deleteTableColumnLabel: "Ştergere coloană"
 })
+	
 
